package com.teamchat.client.sdk.demo;

import java.util.Properties;

import com.teamchat.client.annotations.OnKeyword;
import com.teamchat.client.sdk.TeamchatAPI;
import com.teamchat.client.sdk.chatlets.TextChatlet;
import com.teamchat.client.sdk.pers.ConnectionFactory;
import com.teamchat.client.sdk.pers.MySQLPersistence;
import com.teamchat.client.sdk.pers.PersistenceLayer;
import com.teamchat.client.sdk.pers.PooledConnectionFactory;

/**
 * A simple bot that response to the word "hi" that is posted in
 * any room containing the bot using the MySQL Pooled DBCP Connection.
 * 
 * Please remember to update the parameters viz.
 * bot, password, dbusername, dbPassword, dbHost, dbName
 */
public class DatabasePersistenceDemo {
	
	public static final String bot = "bot@teamchat.com";
	public static final String password = "botpwd";
	public static final String dbUsername = "dbUsername";
	public static final String dbPassword = "dbPassword";
	public static final String dbHost = "dbHost";
	public static final String dbName = "dbName";
	
	/**
	 * This method creates instance of teamchat client, login using specified 
	 * email/password and wait for messages from other users
	 **/
	public static void main(String[] args) {
		
		Properties properties=new Properties();
		properties.setProperty("username", dbUsername);
		properties.setProperty("password", dbPassword);
		properties.setProperty("dbhost", dbHost);
		properties.setProperty("dbname", dbName);
		properties.setProperty("initialSize", "1");
		properties.setProperty("maxIdle", "3");
		properties.setProperty("maxTotal", "5");
		properties.setProperty("maxWaitMillis", "1000");
		ConnectionFactory confact = new PooledConnectionFactory(properties);
		/**
		 * One can also use "new PooledConnectionFactory(Host, Username, Password, Database);"
		 * 
		 *This will initialize the pool with default configuration.
		 */
		PersistenceLayer data = new MySQLPersistence(confact, bot);
		
		TeamchatAPI api =  TeamchatAPI.withCustomPersistence(data)
				.setEmail(bot) 
				.setPassword(password);
				
		api.startReceivingEvents(new HelloWorldBot());
		
	}
	
	/**
	 * This method posts Hello World message, when any user posts hi message to
	 * the logged in user (see main method)
	 **/
	@OnKeyword("hi")
	public void HelloWorld(TeamchatAPI api) {	
		api.perform( 
				api.context().currentRoom().post(
						new TextChatlet("Hello World")
						)
				);
	}

}
